==> jgmenu_4.4.0.orig.tar.gz: jgmenu-4.4.0/README.md <==
<h3 align="center"><img src="https://i.imgur.com/l8uaBVi.png" alt="jgmenu" height="64px"><br />jgmenu </h3>
<p align="center">A simple X11 menu</p>

<p align="center"> <img
src="https://img.shields.io/github/license/johanmalm/jgmenu.svg" /> <a
href="https://www.codacy.com/app/johanmalm/jgmenu?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=johanmalm/jgmenu&amp;utm_campaign=Badge_Grade"><img src="https://api.codacy.com/project/badge/Grade/a154619f17924fcd8ec2be8f338da063" /></a> <br /> <a
href="https://repology.org/metapackage/jgmenu/versions"><img src="https://repology.org/badge/tiny-repos/jgmenu.svg" /></a> <a
href="https://repology.org/metapackage/jgmenu/versions"><img src="https://repology.org/badge/latest-versions/jgmenu.svg"></a> </p>

<h3 align="center">[<a
href="INSTALL.md">Install</a>] [<a
href="NEWS.md">Release&nbsp;Notes</a>] [<a
href="https://jgmenu.github.io/">Website</a>] [<a
href="https://jgmenu.github.io/screenshots.html">Screenshots</a>]</h3>

<img src="https://i.imgur.com/O3E84L3.png" alt="jgmenu" align="right" height="610px" width="512px">

A simple, independent and contemporary-looking X11 menu, designed for scripting, ricing and tweaking.

It is hackable and has a simple code base. It does not depend on any toolkits such as GTK and Qt, but uses cairo and pango to render the menu.

It can optionally use some appearance settings from XSettings, tint2 and GTK.

It can display the following types of menu (or any combination of):

-   bespoke menu using a jgmenu flavoured CSV format
-   application menu (XDG compatible) with localisation support
-   pipe menus
-   openbox XML menu including openbox pipe-menus

It has UTF-8 search support.

# Versioning

We use [semver 2.0.0](http://www.semver.org)

==> jgmenu_4.4.1.orig.tar.gz: jgmenu-4.4.1/README.md <==
<h3 align="center"><img src="https://i.imgur.com/l8uaBVi.png" alt="jgmenu" height="64px"><br />jgmenu </h3>
<p align="center">A simple X11 menu</p>

<p align="center"> <img
src="https://img.shields.io/github/license/johanmalm/jgmenu.svg" /> <a
href="https://repology.org/metapackage/jgmenu/versions"><img src="https://repology.org/badge/tiny-repos/jgmenu.svg" /></a> <a
href="https://repology.org/metapackage/jgmenu/versions"><img src="https://repology.org/badge/latest-versions/jgmenu.svg"></a> </p>

<h3 align="center">[<a
href="INSTALL.md">Install</a>] [<a
href="NEWS.md">Release&nbsp;Notes</a>] [<a
href="https://jgmenu.github.io/">Website</a>] [<a
href="https://jgmenu.github.io/screenshots.html">Screenshots</a>]</h3>

`jgmenu` is simple, independent and contemporary-looking X11 menu, designed for scripting, ricing and tweaking.

It is hackable and has a simple code base. It does not depend on any toolkits such as GTK and Qt, but uses cairo and pango to render the menu.

It can optionally use some appearance settings from XSettings, tint2 and GTK.

It can display the following types of menu (or any combination of):

-   bespoke menu using a jgmenu flavoured CSV format
-   application menu (XDG compatible) with localisation support
-   pipe menus
-   openbox XML menu including openbox pipe-menus

It has UTF-8 search support.

<a href="https://www.youtube.com/watch?v=E-3CFgkfWXE">Video (13:43) showing advanced jgmenu usage on Mabox</a>

<img src="https://i.imgur.com/O3E84L3.png" alt="jgmenu" height="610px" width="512px">

# Versioning

We use [semver 2.0.0](http://www.semver.org)
